==> openGion6.9.6.0_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/02_INDEX/AllDropC.sql <==


ALTER TABLE GE12 DROP CONSTRAINT GE12_UQ;

ALTER TABLE GE12 DROP CONSTRAINT GE12_LUQ;

DROP INDEX GE12_SA;

DROP INDEX GE12_SB;

ALTER TABLE GE15 DROP CONSTRAINT GE15_UQ;

DROP INDEX GE15_SA;

DROP INDEX GE15_SB;

ALTER TABLE GE16 DROP CONSTRAINT GE16_UQ;

ALTER TABLE GE16 DROP CONSTRAINT GE16_LUQ;

ALTER TABLE GE17 DROP CONSTRAINT GE17_UQ;

ALTER TABLE GE17 DROP CONSTRAINT GE17_LUQ;

DROP INDEX GE17_SA;

ALTER TABLE GE20 DROP CONSTRAINT GE20_UQ;

ALTER TABLE GE20 DROP CONSTRAINT GE20_LUQ;

ALTER TABLE GE30 DROP CONSTRAINT GE30_UQ;

DROP INDEX GE30_SA;

DROP INDEX GE30_SB;

ALTER TABLE GE31 DROP CONSTRAINT GE31_UQ;

ALTER TABLE GE31 DROP CONSTRAINT GE31_LUQ;

ALTER TABLE GE32 DROP CONSTRAINT GE32_UQ;

ALTER TABLE GE32 DROP CONSTRAINT GE32_LUQ;

DROP INDEX GE32_SA;

ALTER TABLE GE33 DROP CONSTRAINT GE33_UQ;

ALTER TABLE GE33 DROP CONSTRAINT GE33_LUQ;

ALTER TABLE GE34 DROP CONSTRAINT GE34_UQ;

ALTER TABLE GE34 DROP CONSTRAINT GE34_LUQ;

ALTER TABLE GE36 DROP CONSTRAINT GE36_UQ;

DROP INDEX GE36_SA;

ALTER TABLE GE37 DROP CONSTRAINT GE37_UQ;

ALTER TABLE GE38 DROP CONSTRAINT GE38_UQ;

ALTER TABLE GE38 DROP CONSTRAINT GE38_LUQ;

ALTER TABLE GE39 DROP CONSTRAINT GE39_UQ;

ALTER TABLE GE39 DROP CONSTRAINT GE39_LUQ;

DROP INDEX GE39_SA;

DROP INDEX GE39_SB;

DROP INDEX GE39_SC;

DROP INDEX GE39_SD;

DROP INDEX GE39_SE;

DROP INDEX GE39_SF;

DROP INDEX GE39_SG;

DROP INDEX GE39_SH;

ALTER TABLE GE50 DROP CONSTRAINT GE50_UQ;

DROP INDEX GE50_SA;

DROP INDEX GE50_SB;

DROP INDEX GE50_SC;

ALTER TABLE GE51 DROP CONSTRAINT GE51_UQ;

DROP INDEX GE51_SA;

DROP INDEX GE51_SB;

ALTER TABLE GE52 DROP CONSTRAINT GE52_UQ;

DROP INDEX GE52_SA;

ALTER TABLE GE53 DROP CONSTRAINT GE53_UQ;

DROP INDEX GE53_SA;

ALTER TABLE GE54 DROP CONSTRAINT GE54_UQ;

ALTER TABLE GE55 DROP CONSTRAINT GE55_UQ;

ALTER TABLE GE56 DROP CONSTRAINT GE56_UQ;

DROP INDEX GE56_SA;

ALTER TABLE GE57 DROP CONSTRAINT GE57_UQ;

ALTER TABLE GE58 DROP CONSTRAINT GE58_UQ;

ALTER TABLE GE62 DROP CONSTRAINT GE62_UQ;

DROP INDEX GE62_SA;

DROP INDEX GE62_SB;

ALTER TABLE GE80 DROP CONSTRAINT GE80_UQ;

DROP INDEX GE80_SA;

DROP INDEX GE80_SB;

DROP INDEX GE80_SC;

DROP INDEX GE80_SD;

ALTER TABLE GE81 DROP CONSTRAINT GE81_UQ;

DROP INDEX GE81_SA;

DROP INDEX GE81_SB;

DROP INDEX GE81_SC;

DROP INDEX GE81_SD;

ALTER TABLE GEA03 DROP CONSTRAINT GEA03_UQ;

DROP INDEX GEA03_SA;

ALTER TABLE GEA04 DROP CONSTRAINT GEA04_UQ;

DROP INDEX GEA04_SA;

ALTER TABLE GEA05 DROP CONSTRAINT GEA05_UQ;

DROP INDEX GEA05_SA;

ALTER TABLE GEA06 DROP CONSTRAINT GEA06_UQ;

DROP INDEX GEA06_SA;

ALTER TABLE GEA08 DROP CONSTRAINT GEA08_UQ;

DROP INDEX GEA08_SA;

ALTER TABLE GEA09 DROP CONSTRAINT GEA09_UQ;

DROP INDEX GEA09_SA;

DROP INDEX GEA09_SB;

DROP INDEX GEA09_SC;

ALTER TABLE GEA10 DROP CONSTRAINT GEA10_UQ;

DROP INDEX GEA10_SA;

ALTER TABLE GEA11 DROP CONSTRAINT GEA11_UQ;

DROP INDEX GEA11_SA;

DROP INDEX GEA11_SB;

ALTER TABLE WKGE52_XIN DROP CONSTRAINT WKGE52_XIN_UQ;

ALTER TABLE WKGE54_XIN DROP CONSTRAINT WKGE54_XIN_UQ;

==> openGion7.2.6.1_dev.zip: uap/webapps/ge/db/ORACLE/sql/install/02_INDEX/AllDropC.sql <==


ALTER TABLE GE12 DROP CONSTRAINT GE12_UQ;

ALTER TABLE GE12 DROP CONSTRAINT GE12_LUQ;

DROP INDEX GE12_SA;

DROP INDEX GE12_SB;

ALTER TABLE GE15 DROP CONSTRAINT GE15_UQ;

DROP INDEX GE15_SA;

DROP INDEX GE15_SB;

ALTER TABLE GE16 DROP CONSTRAINT GE16_UQ;

ALTER TABLE GE16 DROP CONSTRAINT GE16_LUQ;

ALTER TABLE GE17 DROP CONSTRAINT GE17_UQ;

ALTER TABLE GE17 DROP CONSTRAINT GE17_LUQ;

DROP INDEX GE17_SA;

ALTER TABLE GE20 DROP CONSTRAINT GE20_UQ;

ALTER TABLE GE20 DROP CONSTRAINT GE20_LUQ;

ALTER TABLE GE30 DROP CONSTRAINT GE30_UQ;

DROP INDEX GE30_SA;

DROP INDEX GE30_SB;

ALTER TABLE GE31 DROP CONSTRAINT GE31_UQ;

ALTER TABLE GE31 DROP CONSTRAINT GE31_LUQ;

ALTER TABLE GE32 DROP CONSTRAINT GE32_UQ;

ALTER TABLE GE32 DROP CONSTRAINT GE32_LUQ;

DROP INDEX GE32_SA;

ALTER TABLE GE33 DROP CONSTRAINT GE33_UQ;

ALTER TABLE GE33 DROP CONSTRAINT GE33_LUQ;

ALTER TABLE GE34 DROP CONSTRAINT GE34_UQ;

ALTER TABLE GE34 DROP CONSTRAINT GE34_LUQ;

ALTER TABLE GE36 DROP CONSTRAINT GE36_UQ;

DROP INDEX GE36_SA;

ALTER TABLE GE37 DROP CONSTRAINT GE37_UQ;

ALTER TABLE GE38 DROP CONSTRAINT GE38_UQ;

ALTER TABLE GE38 DROP CONSTRAINT GE38_LUQ;

ALTER TABLE GE39 DROP CONSTRAINT GE39_UQ;

ALTER TABLE GE39 DROP CONSTRAINT GE39_LUQ;

DROP INDEX GE39_SA;

DROP INDEX GE39_SB;

DROP INDEX GE39_SC;

DROP INDEX GE39_SD;

DROP INDEX GE39_SE;

DROP INDEX GE39_SF;

DROP INDEX GE39_SG;

DROP INDEX GE39_SH;

ALTER TABLE GE50 DROP CONSTRAINT GE50_UQ;

DROP INDEX GE50_SA;

DROP INDEX GE50_SB;

DROP INDEX GE50_SC;

ALTER TABLE GE51 DROP CONSTRAINT GE51_UQ;

DROP INDEX GE51_SA;

DROP INDEX GE51_SB;

ALTER TABLE GE52 DROP CONSTRAINT GE52_UQ;

DROP INDEX GE52_SA;

ALTER TABLE GE53 DROP CONSTRAINT GE53_UQ;

DROP INDEX GE53_SA;

ALTER TABLE GE54 DROP CONSTRAINT GE54_UQ;

ALTER TABLE GE55 DROP CONSTRAINT GE55_UQ;

ALTER TABLE GE56 DROP CONSTRAINT GE56_UQ;

DROP INDEX GE56_SA;

ALTER TABLE GE57 DROP CONSTRAINT GE57_UQ;

ALTER TABLE GE58 DROP CONSTRAINT GE58_UQ;

ALTER TABLE GE70 DROP CONSTRAINT GE70_UQ;

ALTER TABLE GE70 DROP CONSTRAINT GE70_LUQ;

ALTER TABLE GE71 DROP CONSTRAINT GE71_UQ;

ALTER TABLE GE71 DROP CONSTRAINT GE71_LUQ;

ALTER TABLE GE72 DROP CONSTRAINT GE72_UQ;

ALTER TABLE GE72 DROP CONSTRAINT GE72_LUQ;

ALTER TABLE GE80 DROP CONSTRAINT GE80_UQ;

DROP INDEX GE80_SA;

DROP INDEX GE80_SB;

DROP INDEX GE80_SC;

DROP INDEX GE80_SD;

ALTER TABLE GE81 DROP CONSTRAINT GE81_UQ;

DROP INDEX GE81_SA;

DROP INDEX GE81_SB;

DROP INDEX GE81_SC;

DROP INDEX GE81_SD;

ALTER TABLE GEA03 DROP CONSTRAINT GEA03_UQ;

DROP INDEX GEA03_SA;

ALTER TABLE GEA04 DROP CONSTRAINT GEA04_UQ;

DROP INDEX GEA04_SA;

ALTER TABLE GEA05 DROP CONSTRAINT GEA05_UQ;

DROP INDEX GEA05_SA;

ALTER TABLE GEA06 DROP CONSTRAINT GEA06_UQ;

DROP INDEX GEA06_SA;

ALTER TABLE GEA08 DROP CONSTRAINT GEA08_UQ;

DROP INDEX GEA08_SA;

ALTER TABLE GEA09 DROP CONSTRAINT GEA09_UQ;

DROP INDEX GEA09_SA;

DROP INDEX GEA09_SB;

DROP INDEX GEA09_SC;

ALTER TABLE GEA10 DROP CONSTRAINT GEA10_UQ;

DROP INDEX GEA10_SA;

ALTER TABLE GEA11 DROP CONSTRAINT GEA11_UQ;

DROP INDEX GEA11_SA;

DROP INDEX GEA11_SB;

ALTER TABLE WKGE52_XIN DROP CONSTRAINT WKGE52_XIN_UQ;

ALTER TABLE WKGE54_XIN DROP CONSTRAINT WKGE54_XIN_UQ;
